@@ -36,13 +36,15 @@ class OrkutBackend(OAuthBackend):
         return {USERNAME: response['displayName'],
                 'email': response['emails'][0]['value'],
                 'fullname': response['displayName'],
-                'firstname': response['name']['givenName'],
-                'lastname': response['name']['familyName']}
+                'first_name': response['name']['givenName'],
+                'last_name': response['name']['familyName']}
 
 
 class OrkutAuth(BaseGoogleOAuth):
     """Orkut OAuth authentication mechanism"""
     AUTH_BACKEND = OrkutBackend
+    SETTINGS_KEY_NAME = 'ORKUT_CONSUMER_KEY'
+    SETTINGS_SECRET_NAME = 'ORKUT_CONSUMER_SECRET'
 
     def user_data(self, access_token):
         """Loads user data from Orkut service"""
@@ -63,10 +65,6 @@ class OrkutAuth(BaseGoogleOAuth):
         except (simplejson.JSONDecodeError, KeyError):
             return None
 
-    def get_key_and_secret(self):
-        """Return Orkut Consumer Key and Consumer Secret pair"""
-        return settings.ORKUT_CONSUMER_KEY, settings.ORKUT_CONSUMER_SECRET
-
 
 # Backend definition
 BACKENDS = {
